==> kubernetes-annotations-2.9.2-sources.jar: io/dekorate/kubernetes/config/KubernetesConfigFluent.java <==
package io.dekorate.kubernetes.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.dekorate.kubernetes.annotation.ServiceType;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import java.lang.Integer;
import io.dekorate.project.Project;
import io.dekorate.kubernetes.annotation.ImagePullPolicy;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface KubernetesConfigFluent<A extends KubernetesConfigFluent<A>> extends BaseConfigFluent<A>{
  public A withInitContainers(Container... initContainers);
  
  /**
   * This method has been deprecated, please use method buildInitContainers instead.
   */
  @Deprecated
  public io.dekorate.kubernetes.config.Container[] getInitContainers();
  public io.dekorate.kubernetes.config.Container[] buildInitContainers();
  public io.dekorate.kubernetes.config.Container buildInitContainer(Integer index);
  public io.dekorate.kubernetes.config.Container buildFirstInitContainer();
  public io.dekorate.kubernetes.config.Container buildLastInitContainer();
  public io.dekorate.kubernetes.config.Container buildMatchingInitContainer(Predicate<ContainerBuilder> predicate);
  public Boolean hasMatchingInitContainer(java.util.function.Predicate<io.dekorate.kubernetes.config.ContainerBuilder> predicate);
  public A addToInitContainers(java.lang.Integer index,io.dekorate.kubernetes.config.Container item);
  public A setToInitContainers(java.lang.Integer index,io.dekorate.kubernetes.config.Container item);
  public A addToInitContainers(io.dekorate.kubernetes.config.Container... items);
  public A addAllToInitContainers(Collection<io.dekorate.kubernetes.config.Container> items);
  public A removeFromInitContainers(io.dekorate.kubernetes.config.Container... items);
  public A removeAllFromInitContainers(java.util.Collection<io.dekorate.kubernetes.config.Container> items);
  public A removeMatchingFromInitContainers(java.util.function.Predicate<io.dekorate.kubernetes.config.ContainerBuilder> predicate);
  public java.lang.Boolean hasInitContainers();
  public KubernetesConfigFluent.InitContainersNested<A> addNewInitContainer();
  public io.dekorate.kubernetes.config.KubernetesConfigFluent.InitContainersNested<A> addNewInitContainerLike(io.dekorate.kubernetes.config.Container item);
  public io.dekorate.kubernetes.config.KubernetesConfigFluent.InitContainersNested<A> setNewInitContainerLike(java.lang.Integer index,io.dekorate.kubernetes.config.Container item);
  public io.dekorate.kubernetes.config.KubernetesConfigFluent.InitContainersNested<A> editInitContainer(java.lang.Integer index);
  public io.dekorate.kubernetes.config.KubernetesConfigFluent.InitContainersNested<A> editFirstInitContainer();
  public io.dekorate.kubernetes.config.KubernetesConfigFluent.InitContainersNested<A> editLastInitContainer();
  public io.dekorate.kubernetes.config.KubernetesConfigFluent.InitContainersNested<A> editMatchingInitContainer(java.util.function.Predicate<io.dekorate.kubernetes.config.ContainerBuilder> predicate);
  public java.lang.Integer getReplicas();
  public A withReplicas(java.lang.Integer replicas);
  public java.lang.Boolean hasReplicas();
  public DeploymentStrategy getDeploymentStrategy();
  public A withDeploymentStrategy(io.dekorate.kubernetes.config.DeploymentStrategy deploymentStrategy);
  public java.lang.Boolean hasDeploymentStrategy();
  
  /**
   * This method has been deprecated, please use method buildRollingUpdate instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public RollingUpdate getRollingUpdate();
  public io.dekorate.kubernetes.config.RollingUpdate buildRollingUpdate();
  public A withRollingUpdate(io.dekorate.kubernetes.config.RollingUpdate rollingUpdate);
  public java.lang.Boolean hasRollingUpdate();
  public A withNewRollingUpdate(String maxUnavailable,java.lang.String maxSurge);
  public KubernetesConfigFluent.RollingUpdateNested<A> withNewRollingUpdate();
  public io.dekorate.kubernetes.config.KubernetesConfigFluent.RollingUpdateNested<A> withNewRollingUpdateLike(io.dekorate.kubernetes.config.RollingUpdate item);
  public io.dekorate.kubernetes.config.KubernetesConfigFluent.RollingUpdateNested<A> editRollingUpdate();
  public io.dekorate.kubernetes.config.KubernetesConfigFluent.RollingUpdateNested<A> editOrNewRollingUpdate();
  public io.dekorate.kubernetes.config.KubernetesConfigFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(io.dekorate.kubernetes.config.RollingUpdate item);
  public java.lang.Boolean getHeadless();
  public A withHeadless(java.lang.Boolean headless);
  public java.lang.Boolean hasHeadless();
  public A withHeadless();
  public interface InitContainersNested<N> extends Nested<N>,ContainerFluent<KubernetesConfigFluent.InitContainersNested<N>>{
    public N and();
    public N endInitContainer();
    
  }
  public interface RollingUpdateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RollingUpdateFluent<KubernetesConfigFluent.RollingUpdateNested<N>>{
    public N and();
    public N endRollingUpdate();
    
  }
  
}

==> kubernetes-annotations-2.11.2-sources.jar: io/dekorate/kubernetes/config/KubernetesConfigFluent.java <==
package io.dekorate.kubernetes.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.dekorate.kubernetes.annotation.ServiceType;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import java.lang.Integer;
import io.dekorate.project.Project;
import io.dekorate.kubernetes.annotation.ImagePullPolicy;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface KubernetesConfigFluent<A extends KubernetesConfigFluent<A>> extends BaseConfigFluent<A>{
  public A withInitContainers(Container... initContainers);
  
  /**
   * This method has been deprecated, please use method buildInitContainers instead.
   */
  @Deprecated
  public io.dekorate.kubernetes.config.Container[] getInitContainers();
  public io.dekorate.kubernetes.config.Container[] buildInitContainers();
  public io.dekorate.kubernetes.config.Container buildInitContainer(Integer index);
  public io.dekorate.kubernetes.config.Container buildFirstInitContainer();
  public io.dekorate.kubernetes.config.Container buildLastInitContainer();
  public io.dekorate.kubernetes.config.Container buildMatchingInitContainer(Predicate<ContainerBuilder> predicate);
  public Boolean hasMatchingInitContainer(java.util.function.Predicate<io.dekorate.kubernetes.config.ContainerBuilder> predicate);
  public A addToInitContainers(java.lang.Integer index,io.dekorate.kubernetes.config.Container item);
  public A setToInitContainers(java.lang.Integer index,io.dekorate.kubernetes.config.Container item);
  public A addToInitContainers(io.dekorate.kubernetes.config.Container... items);
  public A addAllToInitContainers(Collection<io.dekorate.kubernetes.config.Container> items);
  public A removeFromInitContainers(io.dekorate.kubernetes.config.Container... items);
  public A removeAllFromInitContainers(java.util.Collection<io.dekorate.kubernetes.config.Container> items);
  public A removeMatchingFromInitContainers(java.util.function.Predicate<io.dekorate.kubernetes.config.ContainerBuilder> predicate);
  public java.lang.Boolean hasInitContainers();
  public KubernetesConfigFluent.InitContainersNested<A> addNewInitContainer();
  public io.dekorate.kubernetes.config.KubernetesConfigFluent.InitContainersNested<A> addNewInitContainerLike(io.dekorate.kubernetes.config.Container item);
  public io.dekorate.kubernetes.config.KubernetesConfigFluent.InitContainersNested<A> setNewInitContainerLike(java.lang.Integer index,io.dekorate.kubernetes.config.Container item);
  public io.dekorate.kubernetes.config.KubernetesConfigFluent.InitContainersNested<A> editInitContainer(java.lang.Integer index);
  public io.dekorate.kubernetes.config.KubernetesConfigFluent.InitContainersNested<A> editFirstInitContainer();
  public io.dekorate.kubernetes.config.KubernetesConfigFluent.InitContainersNested<A> editLastInitContainer();
  public io.dekorate.kubernetes.config.KubernetesConfigFluent.InitContainersNested<A> editMatchingInitContainer(java.util.function.Predicate<io.dekorate.kubernetes.config.ContainerBuilder> predicate);
  public java.lang.Integer getReplicas();
  public A withReplicas(java.lang.Integer replicas);
  public java.lang.Boolean hasReplicas();
  public DeploymentStrategy getDeploymentStrategy();
  public A withDeploymentStrategy(io.dekorate.kubernetes.config.DeploymentStrategy deploymentStrategy);
  public java.lang.Boolean hasDeploymentStrategy();
  
  /**
   * This method has been deprecated, please use method buildRollingUpdate instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public RollingUpdate getRollingUpdate();
  public io.dekorate.kubernetes.config.RollingUpdate buildRollingUpdate();
  public A withRollingUpdate(io.dekorate.kubernetes.config.RollingUpdate rollingUpdate);
  public java.lang.Boolean hasRollingUpdate();
  public A withNewRollingUpdate(String maxUnavailable,java.lang.String maxSurge);
  public KubernetesConfigFluent.RollingUpdateNested<A> withNewRollingUpdate();
  public io.dekorate.kubernetes.config.KubernetesConfigFluent.RollingUpdateNested<A> withNewRollingUpdateLike(io.dekorate.kubernetes.config.RollingUpdate item);
  public io.dekorate.kubernetes.config.KubernetesConfigFluent.RollingUpdateNested<A> editRollingUpdate();
  public io.dekorate.kubernetes.config.KubernetesConfigFluent.RollingUpdateNested<A> editOrNewRollingUpdate();
  public io.dekorate.kubernetes.config.KubernetesConfigFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(io.dekorate.kubernetes.config.RollingUpdate item);
  
  /**
   * This method has been deprecated, please use method buildIngress instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public Ingress getIngress();
  public io.dekorate.kubernetes.config.Ingress buildIngress();
  public A withIngress(io.dekorate.kubernetes.config.Ingress ingress);
  public java.lang.Boolean hasIngress();
  public A withNewIngress(java.lang.String host,java.lang.Boolean expose,java.lang.String tlsSecretName,java.lang.String[] tlsHosts);
  public KubernetesConfigFluent.IngressNested<A> withNewIngress();
  public io.dekorate.kubernetes.config.KubernetesConfigFluent.IngressNested<A> withNewIngressLike(io.dekorate.kubernetes.config.Ingress item);
  public io.dekorate.kubernetes.config.KubernetesConfigFluent.IngressNested<A> editIngress();
  public io.dekorate.kubernetes.config.KubernetesConfigFluent.IngressNested<A> editOrNewIngress();
  public io.dekorate.kubernetes.config.KubernetesConfigFluent.IngressNested<A> editOrNewIngressLike(io.dekorate.kubernetes.config.Ingress item);
  public java.lang.Boolean getHeadless();
  public A withHeadless(java.lang.Boolean headless);
  public java.lang.Boolean hasHeadless();
  public A withHeadless();
  public interface InitContainersNested<N> extends Nested<N>,ContainerFluent<KubernetesConfigFluent.InitContainersNested<N>>{
    public N and();
    public N endInitContainer();
    
  }
  public interface RollingUpdateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RollingUpdateFluent<KubernetesConfigFluent.RollingUpdateNested<N>>{
    public N and();
    public N endRollingUpdate();
    
  }
  public interface IngressNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,IngressFluent<KubernetesConfigFluent.IngressNested<N>>{
    public N and();
    public N endIngress();
    
  }
  
}
